P4 to Git Change 1589087 by skudchad@skudchad_rocm on 2018/08/02 20:10:02
SWDEV-145570 - [HIP] - hipHccModuleLaunchKernel needs to be a c++ sym Affected files ... ... //depot/stg/opencl/drivers/opencl/api/hip/hip_hcc.map.in#9 edit ... //depot/stg/opencl/drivers/opencl/api/hip/hip_module.cpp#14 edit
This commit is contained in:
@@ -107,7 +107,6 @@ global:
|
||||
hipModuleGetGlobal;
|
||||
hipModuleLaunchKernel;
|
||||
hipModuleLaunchKernelExt;
|
||||
hipHccModuleLaunchKernel;
|
||||
hipModuleLoad;
|
||||
hipModuleLoadData;
|
||||
hipModuleLoadDataEx;
|
||||
@@ -166,6 +165,7 @@ global:
|
||||
hipHccGetAcceleratorView*;
|
||||
hipCreateSurfaceObject*;
|
||||
hipDestroySurfaceObject*;
|
||||
hipHccModuleLaunchKernel*;
|
||||
};
|
||||
local:
|
||||
*;
|
||||
|
||||
+18
-7
@@ -244,17 +244,28 @@ hipError_t hipModuleLaunchKernel(hipFunction_t f,
|
||||
sharedMemBytes, hStream, kernelParams, extra, nullptr, nullptr);
|
||||
}
|
||||
|
||||
hipError_t hipModuleLaunchKernelExt(hipFunction_t f,
|
||||
uint32_t gridDimX, uint32_t gridDimY, uint32_t gridDimZ,
|
||||
uint32_t blockDimX, uint32_t blockDimY, uint32_t blockDimZ,
|
||||
uint32_t sharedMemBytes, hipStream_t hStream,
|
||||
void **kernelParams, void **extra,
|
||||
hipEvent_t startEvent, hipEvent_t stopEvent)
|
||||
hipError_t hipHccModuleLaunchKernel(hipFunction_t f, uint32_t gridDimX,
|
||||
uint32_t gridDimY, uint32_t gridDimZ,
|
||||
uint32_t blockDimX, uint32_t blockDimY,
|
||||
uint32_t blockDimZ, size_t sharedMemBytes,
|
||||
hipStream_t hStream, void** kernelParams, void** extra,
|
||||
hipEvent_t startEvent,
|
||||
hipEvent_t stopEvent)
|
||||
{
|
||||
return ihipModuleLaunchKernel(f, gridDimX, gridDimY, gridDimZ, blockDimX, blockDimY, blockDimZ,
|
||||
sharedMemBytes, hStream, kernelParams, extra, startEvent, stopEvent);
|
||||
}
|
||||
|
||||
const auto& hipHccModuleLaunchKernel = hipModuleLaunchKernelExt;
|
||||
hipError_t hipModuleLaunchKernelExt(hipFunction_t f, uint32_t gridDimX,
|
||||
uint32_t gridDimY, uint32_t gridDimZ,
|
||||
uint32_t blockDimX, uint32_t blockDimY,
|
||||
uint32_t blockDimZ, size_t sharedMemBytes,
|
||||
hipStream_t hStream, void** kernelParams, void** extra,
|
||||
hipEvent_t startEvent,
|
||||
hipEvent_t stopEvent)
|
||||
{
|
||||
return ihipModuleLaunchKernel(f, gridDimX, gridDimY, gridDimZ, blockDimX, blockDimY, blockDimZ,
|
||||
sharedMemBytes, hStream, kernelParams, extra, startEvent, stopEvent);
|
||||
}
|
||||
|
||||
|
||||
|
||||
Reference in New Issue
Block a user